==> kubernetes-model-core-6.1.1-sources.jar: io/fabric8/kubernetes/api/model/APIResourceListFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class APIResourceListFluentImpl<A extends APIResourceListFluent<A>> extends BaseFluent<A> implements APIResourceListFluent<A>{
  public APIResourceListFluentImpl() {
  }
  public APIResourceListFluentImpl(APIResourceList instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withGroupVersion(instance.getGroupVersion()); 
    this.withKind(instance.getKind()); 
    this.withResources(instance.getResources()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String apiVersion;
  private String groupVersion;
  private String kind;
  private ArrayList<APIResourceBuilder> resources = new ArrayList<APIResourceBuilder>();
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getGroupVersion() {
    return this.groupVersion;
  }
  public A withGroupVersion(String groupVersion) {
    this.groupVersion=groupVersion; return (A) this;
  }
  public Boolean hasGroupVersion() {
    return this.groupVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  public A addToResources(Integer index,APIResource item) {
    if (this.resources == null) {this.resources = new ArrayList<APIResourceBuilder>();}
    APIResourceBuilder builder = new APIResourceBuilder(item);_visitables.get("resources").add(index >= 0 ? index : _visitables.get("resources").size(), builder);this.resources.add(index >= 0 ? index : resources.size(), builder); return (A)this;
  }
  public A setToResources(Integer index,APIResource item) {
    if (this.resources == null) {this.resources = new ArrayList<APIResourceBuilder>();}
    APIResourceBuilder builder = new APIResourceBuilder(item);
    if (index < 0 || index >= _visitables.get("resources").size()) { _visitables.get("resources").add(builder); } else { _visitables.get("resources").set(index, builder);}
    if (index < 0 || index >= resources.size()) { resources.add(builder); } else { resources.set(index, builder);}
     return (A)this;
  }
  public A addToResources(io.fabric8.kubernetes.api.model.APIResource... items) {
    if (this.resources == null) {this.resources = new ArrayList<APIResourceBuilder>();}
    for (APIResource item : items) {APIResourceBuilder builder = new APIResourceBuilder(item);_visitables.get("resources").add(builder);this.resources.add(builder);} return (A)this;
  }
  public A addAllToResources(Collection<APIResource> items) {
    if (this.resources == null) {this.resources = new ArrayList<APIResourceBuilder>();}
    for (APIResource item : items) {APIResourceBuilder builder = new APIResourceBuilder(item);_visitables.get("resources").add(builder);this.resources.add(builder);} return (A)this;
  }
  public A removeFromResources(io.fabric8.kubernetes.api.model.APIResource... items) {
    for (APIResource item : items) {APIResourceBuilder builder = new APIResourceBuilder(item);_visitables.get("resources").remove(builder);if (this.resources != null) {this.resources.remove(builder);}} return (A)this;
  }
  public A removeAllFromResources(Collection<APIResource> items) {
    for (APIResource item : items) {APIResourceBuilder builder = new APIResourceBuilder(item);_visitables.get("resources").remove(builder);if (this.resources != null) {this.resources.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromResources(Predicate<APIResourceBuilder> predicate) {
    if (resources == null) return (A) this;
    final Iterator<APIResourceBuilder> each = resources.iterator();
    final List visitables = _visitables.get("resources");
    while (each.hasNext()) {
      APIResourceBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildResources instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<APIResource> getResources() {
    return resources != null ? build(resources) : null;
  }
  public List<APIResource> buildResources() {
    return resources != null ? build(resources) : null;
  }
  public APIResource buildResource(Integer index) {
    return this.resources.get(index).build();
  }
  public APIResource buildFirstResource() {
    return this.resources.get(0).build();
  }
  public APIResource buildLastResource() {
    return this.resources.get(resources.size() - 1).build();
  }
  public APIResource buildMatchingResource(Predicate<APIResourceBuilder> predicate) {
    for (APIResourceBuilder item: resources) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingResource(Predicate<APIResourceBuilder> predicate) {
    for (APIResourceBuilder item: resources) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withResources(List<APIResource> resources) {
    if (this.resources != null) { _visitables.get("resources").removeAll(this.resources);}
    if (resources != null) {this.resources = new ArrayList(); for (APIResource item : resources){this.addToResources(item);}} else { this.resources = null;} return (A) this;
  }
  public A withResources(io.fabric8.kubernetes.api.model.APIResource... resources) {
    if (this.resources != null) {this.resources.clear();}
    if (resources != null) {for (APIResource item :resources){ this.addToResources(item);}} return (A) this;
  }
  public Boolean hasResources() {
    return resources != null && !resources.isEmpty();
  }
  public APIResourceListFluent.ResourcesNested<A> addNewResource() {
    return new APIResourceListFluentImpl.ResourcesNestedImpl();
  }
  public APIResourceListFluent.ResourcesNested<A> addNewResourceLike(APIResource item) {
    return new APIResourceListFluentImpl.ResourcesNestedImpl(-1, item);
  }
  public APIResourceListFluent.ResourcesNested<A> setNewResourceLike(Integer index,APIResource item) {
    return new APIResourceListFluentImpl.ResourcesNestedImpl(index, item);
  }
  public APIResourceListFluent.ResourcesNested<A> editResource(Integer index) {
    if (resources.size() <= index) throw new RuntimeException("Can't edit resources. Index exceeds size.");
    return setNewResourceLike(index, buildResource(index));
  }
  public APIResourceListFluent.ResourcesNested<A> editFirstResource() {
    if (resources.size() == 0) throw new RuntimeException("Can't edit first resources. The list is empty.");
    return setNewResourceLike(0, buildResource(0));
  }
  public APIResourceListFluent.ResourcesNested<A> editLastResource() {
    int index = resources.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last resources. The list is empty.");
    return setNewResourceLike(index, buildResource(index));
  }
  public APIResourceListFluent.ResourcesNested<A> editMatchingResource(Predicate<APIResourceBuilder> predicate) {
    int index = -1;
    for (int i=0;i<resources.size();i++) { 
    if (predicate.test(resources.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching resources. No match found.");
    return setNewResourceLike(index, buildResource(index));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    APIResourceListFluentImpl that = (APIResourceListFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (groupVersion != null ? !groupVersion.equals(that.groupVersion) :that.groupVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (resources != null ? !resources.equals(that.resources) :that.resources != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  groupVersion,  kind,  resources,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (groupVersion != null) { sb.append("groupVersion:"); sb.append(groupVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (resources != null && !resources.isEmpty()) { sb.append("resources:"); sb.append(resources + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ResourcesNestedImpl<N> extends APIResourceFluentImpl<APIResourceListFluent.ResourcesNested<N>> implements APIResourceListFluent.ResourcesNested<N>,Nested<N>{
    ResourcesNestedImpl(Integer index,APIResource item) {
      this.index = index;
      this.builder = new APIResourceBuilder(this, item);
    }
    ResourcesNestedImpl() {
      this.index = -1;
      this.builder = new APIResourceBuilder(this);
    }
    APIResourceBuilder builder;
    Integer index;
    public N and() {
      return (N) APIResourceListFluentImpl.this.setToResources(index,builder.build());
    }
    public N endResource() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-core-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/APIResourceListFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class APIResourceListFluentImpl<A extends APIResourceListFluent<A>> extends BaseFluent<A> implements APIResourceListFluent<A>{
  public APIResourceListFluentImpl() {
  }
  public APIResourceListFluentImpl(APIResourceList instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withGroupVersion(instance.getGroupVersion());
      this.withKind(instance.getKind());
      this.withResources(instance.getResources());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private String groupVersion;
  private String kind;
  private ArrayList<APIResourceBuilder> resources = new ArrayList<APIResourceBuilder>();
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getGroupVersion() {
    return this.groupVersion;
  }
  public A withGroupVersion(String groupVersion) {
    this.groupVersion=groupVersion; return (A) this;
  }
  public Boolean hasGroupVersion() {
    return this.groupVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  public A addToResources(int index,APIResource item) {
    if (this.resources == null) {this.resources = new ArrayList<APIResourceBuilder>();}
    APIResourceBuilder builder = new APIResourceBuilder(item);
    if (index < 0 || index >= resources.size()) { _visitables.get("resources").add(builder); resources.add(builder); } else { _visitables.get("resources").add(index, builder); resources.add(index, builder);}
    return (A)this;
  }
  public A setToResources(int index,APIResource item) {
    if (this.resources == null) {this.resources = new ArrayList<APIResourceBuilder>();}
    APIResourceBuilder builder = new APIResourceBuilder(item);
    if (index < 0 || index >= resources.size()) { _visitables.get("resources").add(builder); resources.add(builder); } else { _visitables.get("resources").set(index, builder); resources.set(index, builder);}
    return (A)this;
  }
  public A addToResources(io.fabric8.kubernetes.api.model.APIResource... items) {
    if (this.resources == null) {this.resources = new ArrayList<APIResourceBuilder>();}
    for (APIResource item : items) {APIResourceBuilder builder = new APIResourceBuilder(item);_visitables.get("resources").add(builder);this.resources.add(builder);} return (A)this;
  }
  public A addAllToResources(Collection<APIResource> items) {
    if (this.resources == null) {this.resources = new ArrayList<APIResourceBuilder>();}
    for (APIResource item : items) {APIResourceBuilder builder = new APIResourceBuilder(item);_visitables.get("resources").add(builder);this.resources.add(builder);} return (A)this;
  }
  public A removeFromResources(io.fabric8.kubernetes.api.model.APIResource... items) {
    for (APIResource item : items) {APIResourceBuilder builder = new APIResourceBuilder(item);_visitables.get("resources").remove(builder);if (this.resources != null) {this.resources.remove(builder);}} return (A)this;
  }
  public A removeAllFromResources(Collection<APIResource> items) {
    for (APIResource item : items) {APIResourceBuilder builder = new APIResourceBuilder(item);_visitables.get("resources").remove(builder);if (this.resources != null) {this.resources.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromResources(Predicate<APIResourceBuilder> predicate) {
    if (resources == null) return (A) this;
    final Iterator<APIResourceBuilder> each = resources.iterator();
    final List visitables = _visitables.get("resources");
    while (each.hasNext()) {
      APIResourceBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildResources instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<APIResource> getResources() {
    return resources != null ? build(resources) : null;
  }
  public List<APIResource> buildResources() {
    return resources != null ? build(resources) : null;
  }
  public APIResource buildResource(int index) {
    return this.resources.get(index).build();
  }
  public APIResource buildFirstResource() {
    return this.resources.get(0).build();
  }
  public APIResource buildLastResource() {
    return this.resources.get(resources.size() - 1).build();
  }
  public APIResource buildMatchingResource(Predicate<APIResourceBuilder> predicate) {
    for (APIResourceBuilder item: resources) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingResource(Predicate<APIResourceBuilder> predicate) {
    for (APIResourceBuilder item: resources) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withResources(List<APIResource> resources) {
    if (this.resources != null) { _visitables.get("resources").clear();}
    if (resources != null) {this.resources = new ArrayList(); for (APIResource item : resources){this.addToResources(item);}} else { this.resources = null;} return (A) this;
  }
  public A withResources(io.fabric8.kubernetes.api.model.APIResource... resources) {
    if (this.resources != null) {this.resources.clear(); _visitables.remove("resources"); }
    if (resources != null) {for (APIResource item :resources){ this.addToResources(item);}} return (A) this;
  }
  public Boolean hasResources() {
    return resources != null && !resources.isEmpty();
  }
  public APIResourceListFluentImpl.ResourcesNested<A> addNewResource() {
    return new APIResourceListFluentImpl.ResourcesNestedImpl();
  }
  public APIResourceListFluentImpl.ResourcesNested<A> addNewResourceLike(APIResource item) {
    return new APIResourceListFluentImpl.ResourcesNestedImpl(-1, item);
  }
  public APIResourceListFluentImpl.ResourcesNested<A> setNewResourceLike(int index,APIResource item) {
    return new APIResourceListFluentImpl.ResourcesNestedImpl(index, item);
  }
  public APIResourceListFluentImpl.ResourcesNested<A> editResource(int index) {
    if (resources.size() <= index) throw new RuntimeException("Can't edit resources. Index exceeds size.");
    return setNewResourceLike(index, buildResource(index));
  }
  public APIResourceListFluentImpl.ResourcesNested<A> editFirstResource() {
    if (resources.size() == 0) throw new RuntimeException("Can't edit first resources. The list is empty.");
    return setNewResourceLike(0, buildResource(0));
  }
  public APIResourceListFluentImpl.ResourcesNested<A> editLastResource() {
    int index = resources.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last resources. The list is empty.");
    return setNewResourceLike(index, buildResource(index));
  }
  public APIResourceListFluentImpl.ResourcesNested<A> editMatchingResource(Predicate<APIResourceBuilder> predicate) {
    int index = -1;
    for (int i=0;i<resources.size();i++) { 
    if (predicate.test(resources.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching resources. No match found.");
    return setNewResourceLike(index, buildResource(index));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    APIResourceListFluentImpl that = (APIResourceListFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(groupVersion, that.groupVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(resources, that.resources)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  groupVersion,  kind,  resources,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (groupVersion != null) { sb.append("groupVersion:"); sb.append(groupVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (resources != null && !resources.isEmpty()) { sb.append("resources:"); sb.append(resources + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ResourcesNestedImpl<N> extends APIResourceFluentImpl<APIResourceListFluentImpl.ResourcesNested<N>> implements APIResourceListFluentImpl.ResourcesNested<N>,Nested<N>{
    ResourcesNestedImpl(int index,APIResource item) {
      this.index = index;
      this.builder = new APIResourceBuilder(this, item);
    }
    ResourcesNestedImpl() {
      this.index = -1;
      this.builder = new APIResourceBuilder(this);
    }
    APIResourceBuilder builder;
    int index;
    public N and() {
      return (N) APIResourceListFluentImpl.this.setToResources(index,builder.build());
    }
    public N endResource() {
      return and();
    }
    
  }
  
}
